@@ -10,34 +10,43 @@ use vars qw(@ISA @EXPORT @EXPORT_OK);
 use Exporter 'import';
 
 # Exporting the implemented subroutine.
-our @EXPORT = qw(
-    sign
-);
+# our @EXPORT = qw(
+#     sign
+# );
 
 # Base class of this (tron_addr) module.
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 1;
+
 __END__
 
 =head1 NAME
 
-CryptoTron - Perl extension for use with crypto coin Tron blockchain
+CryptoTron - Perl extension for use with the crypto coin Tron blockchain
 
 =head1 SYNOPSIS
 
-None
+  use CryptoTron::SignTx
+  use CryptoTron::ClaimReward
+  use CryptoTron::AddressConvert
+  use CryptoTron::AddressCheck
+  use CryptoTron::AddrTools
 
 =head1 DESCRIPTION
 
-None
+The module provides methods to query the blockchain of the crypto coin Tron. 
 
 =head1 SEE ALSO
 
-None
+Try::Catch
+
+Inline::Python
+
+Bitcoin::Crypto::Base58
 
 =head1 AUTHOR
 
